@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 import fire
-from bioat import about, Bam, Fastx, HiC, Mgi, System, Table, __version__
+from bioat import about, Bam, Fastx, HiC, Mgi, System, Table, TargetedDeepSequencing, __version__
 
 
 class Cli(object):
@@ -19,7 +19,9 @@ class Cli(object):
         self.mgi = Mgi()
         # self.system = System()
         self.table = Table()
+        self.targeted_deep_sequencing = TargetedDeepSequencing()
 
+    @classmethod
     def about(self):
         """Print information about <bioat>.
         """
@@ -36,6 +38,7 @@ class Cli(object):
                     if not sub_att.startswith('_'):
                         print(f'  ├── {sub_att}')
 
+    @classmethod
     def version(self):
         """Print version information.
         """
